***Table 1--bills per congress***
clear
set more off
use "PIPC.dta"
g first = substr(issue,1,1)
destring first, replace
destring issue, replace
*Defense
g defense = first == 3
replace defense = 1 if issue >= 110 & issue <= 119
*Social Welfare, Poverty Programs, Housing and Rent Subsidies
g welfare = issue >= 810 & issue <= 819
replace welfare = 1 if issue >= 830 & issue <= 839
replace welfare = 1 if issue == 173
replace welfare = 1 if issue == 864
*Agriculture
g agriculture = issue >= 200 & issue <=209
replace agriculture = 1 if issue >= 910 & issue <= 919
*Education
g education = issue == 174
replace education = 1 if issue >=850 & issue <=859
*Seniors' Issues: Social Security, Medicare, Pensions
g senior = issue >= 800 & issue <= 809
replace senior = 1 if issue == 577
*Civil Rights Issues (Just Racial Rights Issues)
g civilrights = issue == 108 | issue == 176
replace civilrights = 1 if issue >= 720 & issue <= 739
replace civilrights = 0 if issue == 724 | issue == 730 | issue == 732 | issue == 733 | issue == 735
*Public Transportation
g publictransportation = issue == 211 | issue == 212 | issue == 921 | issue == 922 | issue == 925 | issue == 927
*Energy Issues
g energy = issue >=130 & issue <= 139
replace energy = 1 if issue == 161 | issue == 163 | issue == 316 | issue == 392 | first == 6
keep if cong >= 108 & cong <= 111
keep cong voteview defense welfare agriculture publictransportation education senior civilrights energy
rename voteview bill
drop if defense + welfare + agriculture + education + senior + publictransportation + civilrights + energy == 0
sort cong bill
g issue = ""
foreach i in agriculture civilrights defense education energy publictransportation senior welfare {
replace issue = "`i'" if `i' == 1
}
keep cong bill issue
egen total = count(bill), by(issue)
g billspercong = round(total/4)
keep issue billspercong
sort issue
drop if issue == issue[_n-1]
browse

***Table 1--close elections***
clear
set more off
local cutoff = .1
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
sum `i' if _n == 438 - ceil(437*`cutoff')
replace `i' = `i' >= r(mean)
}
rename poverty demo_welfare
rename military demo_defense
g demo_military = demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist cong
merge state dist cong using "HouseElectionResults.dta"
tab _merge
drop if _merge == 2
drop _merge
foreach i of varlist voteshare-absrv {
replace `i' = . if treatment != rep
}
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
tab demo_`i' if absrv < .1
}

***Figure 1***
clear
set more off
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
replace `i' = _n
sum `i'
replace `i' = 100*((`i' - r(min))/(r(max) - r(min)))
}
rename poverty demo_welfare
rename military demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
egen state_dist_cong = group(state dist cong) 
reshape long cvp_ cvp_non_ demo_, i(state_dist_cong) j(issue) string
g demeaned_cvp = .
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
areg cvp_ if issue == "`i'", a(cong)
predict pcvp
predict rcvp, residual
g dcvp = pcvp + rcvp
replace demeaned_cvp = dcvp if issue == "`i'"
drop pcvp rcvp dcvp
}
g cvp_dem = demeaned_cvp if rep == 0
g cvp_rep = demeaned_cvp if rep == 1
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
graph twoway (scatter cvp_dem cvp_rep demo_) (lpoly cvp_dem demo_) (lpoly cvp_rep demo_) (lpoly demeaned_cvp demo_) if issue == "`i'"
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) boxstyle(shadestyle(color(white)) linestyle(color(white))) editcopy
gr_edit .xaxis1.reset_rule 0 100 50, tickset(major) ruletype(range) 
gr_edit .yaxis1.reset_rule -.5 .5 .5, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush CVP
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Issue Interest (percentile)
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(size(tiny) fillcolor(blue) linestyle(color(blue))) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(size(tiny) fillcolor(red) linestyle(color(red))) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(blue) width(thick)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(red) width(thick)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(gs8) width(thick)) editcopy
graph save "descriptive_`i'.gph", replace
}
graph combine "descriptive_agriculture.gph" "descriptive_civilrights.gph" "descriptive_defense.gph" ///
"descriptive_education.gph" "descriptive_energy.gph" "descriptive_pubtrans.gph" "descriptive_senior.gph" "descriptive_welfare.gph", col(3)
gr_edit .style.editstyle margin(zero) boxstyle(shadestyle(color(white)) linestyle(color(white))) editcopy
forvalues i = 1/5 {
gr_edit .plotregion1.graph`i'.xaxis1.title.draw_view.setstyle, style(no)
}
foreach i in 2 3 5 6 8 {
gr_edit .plotregion1.graph`i'.yaxis1.title.draw_view.setstyle, style(no)
}
forvalues i = 1/8 {
gr_edit .plotregion1.graph`i'.title.text = {}
gr_edit .plotregion1.graph`i'.title.style.editstyle size(medium) color(black) editcopy
}
gr_edit .plotregion1.graph1.title.text.Arrpush Agriculture
gr_edit .plotregion1.graph2.title.text.Arrpush Civil Rights
gr_edit .plotregion1.graph3.title.text.Arrpush Defense
gr_edit .plotregion1.graph4.title.text.Arrpush Education
gr_edit .plotregion1.graph5.title.text.Arrpush Energy
gr_edit .plotregion1.graph6.title.text.Arrpush Public Transportation
gr_edit .plotregion1.graph7.title.text.Arrpush Senior Issues
gr_edit .plotregion1.graph8.title.text.Arrpush Welfare
graph save "Figure1.gph", replace
graph export "Figure1.eps", as(eps) replace


***Figure 2 and Table 2***
clear
set more off
local cutoff = .1
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
sum `i' if _n == 438 - ceil(437*`cutoff')
replace `i' = `i' >= r(mean)
}
rename poverty demo_welfare
rename military demo_defense
g demo_military = demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist cong
merge state dist cong using "HouseElectionResults.dta"
tab _merge
drop if _merge == 2
drop _merge
foreach i of varlist voteshare-absrv {
replace `i' = . if treatment != rep
}
egen state_dist = group(state dist)
egen state_dist_cong = group(state dist cong) 
reshape long cvp_ cvp_non_ demo_, i(state_dist_cong) j(issue) string
g rep_demo_ = rep*demo_
egen issue_cong_demo = group(issue cong demo_)
egen issue_cong = group(issue cong)
egen issue_dist = group(issue state_dist)
egen cong_demo = group(cong demo_)
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
forvalues j = 1/4 {
g rv`j'_`i' = 0
replace rv`j'_`i' = rv`j' if issue == "`i'"
g rv`j'_demo_`i' = rv`j'_`i'*demo_
}
}
forvalues j = 1/4 {
g rv`j'_demo = rv`j'*demo_
}
*Figure 2*
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
preserve
keep if issue == "`i'"
areg cvp_ rep rv1-rv4 if demo_ == 0 & absrv < .5, a(cong) cluster(state_dist)
predict y1_low if rep == 1
predict y0_low if rep == 0
predict raw_low if demo_ == 0, residual
replace raw_low = raw_low + y1_low if rep == 1
replace raw_low = raw_low + y0_low if rep == 0
areg cvp_ rep rv1-rv4 if demo_ == 1 & absrv < .5, a(cong) cluster(state_dist)
predict y1_high if rep == 1
predict y0_high if rep == 0
predict raw_high if demo_ == 1, residual
replace raw_high = raw_high + y1_high if rep == 1
replace raw_high = raw_high + y0_high if rep == 0
g bin = (floor(voteshare*100) + .5)/100
egen avg_high = mean(raw_high), by(bin)
egen avg_low = mean(raw_low), by(bin)
sort voteshare
graph twoway (scatter avg_low avg_high bin) (line y1_low y0_low y1_high y0_high voteshare) if absrv < .2, xline(.5)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Republican Vote Share
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush CVP
gr_edit .style.editstyle margin(vsmall) boxstyle(shadestyle(color(white)) linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .plotregion1.plot1.style.editstyle marker(size(small) fillcolor(gs8) linestyle(color(gs8))) editcopy
gr_edit .plotregion1.plot2.style.editstyle marker(size(small) fillcolor(black) linestyle(color(black))) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(gs8) width(thick)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(gs8) width(thick)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(black) width(thick)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(black) width(thick)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black) pattern(dash)) editcopy
graph save "RD_`i'.gph", replace
restore
}
graph use "RD_agriculture.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Agriculture
graph save "RD_agriculture.gph", replace

graph use "RD_civilrights.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Civil Rights 
graph save "RD_civilrights.gph", replace
graph use "RD_defense.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Defense 
graph save "RD_defense.gph", replace
graph use "RD_education.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Education
graph save "RD_education.gph", replace
graph use "RD_energy.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Energy
graph save "RD_energy.gph", replace
graph use "RD_pubtrans.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Public Transportation
graph save "RD_pubtrans.gph", replace
graph use "RD_senior.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Senior Issues
graph save "RD_senior.gph", replace
graph use "RD_welfare.gph"
gr_edit .title.style.editstyle size(medium) color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Welfare
graph save "RD_welfare.gph", replace
graph combine RD_agriculture.gph RD_civilrights.gph RD_defense.gph RD_education.gph RD_energy.gph RD_pubtrans.gph RD_senior.gph RD_welfare.gph, col(3)
gr_edit .style.editstyle margin(zero) boxstyle(shadestyle(color(white)) linestyle(color(white))) editcopy
foreach i in 2 3 5 6 {
gr_edit .plotregion1.graph`i'.yaxis1.title.draw_view.setstyle, style(no)
}
forvalues i = 1/5 {
gr_edit .plotregion1.graph`i'.xaxis1.title.draw_view.setstyle, style(no)
}
gr_edit .plotregion1.graph1.plotregion1.AddTextBox added_text editor .1612832538829744 .3048624960390118
gr_edit .plotregion1.graph1.plotregion1.added_text_new = 1
gr_edit .plotregion1.graph1.plotregion1.added_text_rec = 1
gr_edit .plotregion1.graph1.plotregion1.added_text[1].style.editstyle  angle(default) size(vsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.graph1.plotregion1.added_text[1].text = {}
gr_edit .plotregion1.graph1.plotregion1.added_text[1].text.Arrpush High-Interest
gr_edit .plotregion1.graph1.plotregion1.AddLine added_lines editor .3424465627564806 .127119438067099 .3727562939802458 -.077863456828154
gr_edit .plotregion1.graph1.plotregion1.added_lines_new = 1
gr_edit .plotregion1.graph1.plotregion1.added_lines_rec = 1
gr_edit .plotregion1.graph1.plotregion1.added_lines[1].style.editstyle  linestyle( width(thin) color(black) pattern(solid)) headstyle( symbol(circle) linestyle( width(thin) color(black) pattern(solid)) fillcolor(black) size(medium) angle(stdarrow) backsymbol(none) backline( width(thin) color(black) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) headpos(head) editcopy
gr_edit .plotregion1.graph1.plotregion1.AddTextBox added_text editor .1869061157448805 .5521899028249355
gr_edit .plotregion1.graph1.plotregion1.added_text_new = 2
gr_edit .plotregion1.graph1.plotregion1.added_text_rec = 2
gr_edit .plotregion1.graph1.plotregion1.added_text[2].style.editstyle  angle(default) size(vsmall) color(gs8) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.graph1.plotregion1.added_text[2].text = {}
gr_edit .plotregion1.graph1.plotregion1.added_text[2].text.Arrpush Low-Interest
gr_edit .plotregion1.graph1.plotregion1.AddLine added_lines editor .5400660103354295 .3619956718012415 .5618890168165404 .2125289776067876
gr_edit .plotregion1.graph1.plotregion1.added_lines_new = 2
gr_edit .plotregion1.graph1.plotregion1.added_lines_rec = 2
gr_edit .plotregion1.graph1.plotregion1.added_lines[2].style.editstyle  linestyle( width(thin) color(gs8) pattern(solid)) headstyle( symbol(circle) linestyle( width(thin) color(gs8) pattern(solid)) fillcolor(gs8) size(medium) angle(stdarrow) backsymbol(none) backline( width(thin) color(gs8) pattern(solid)) backcolor(black) backsize(zero) backangle(stdarrow)) headpos(tail) editcopy
graph save "Figure2.gph", replace
graph export "Figure2.eps", as(eps) replace
*Table 2*
postfile Table2 uninterested uninterested_se interested interested_se difference difference_se using "Table2.dta", replace
*issue-by-issue
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
areg cvp_ rep rv1-rv4 if issue == "`i'" & demo_ == 0 & absrv < .5, a(cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep] 
areg cvp_ rep rv1-rv4 if issue == "`i'" & demo_ == 1 & absrv < .5, a(cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ rv1-rv4 rv*_demo if issue == "`i'" & absrv < .5, a(cong_demo) cluster(state_dist)
post Table2 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
}
*pooled
areg cvp_ rep rv* if absrv < .5 & demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_ rep rv* if absrv < .5 & demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ rv* if absrv < .5, a(issue_cong_demo) cluster(state_dist)
post Table2 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
*placebo
areg cvp_non_ rep rv* if absrv < .5 & demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_non_ rep rv* if absrv < .5 & demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_non_ rep rep_demo_ rv* if absrv < .5, a(issue_cong_demo) cluster(state_dist)
post Table2 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
postclose Table2
clear
set more off
use "Table2.dta"
g issue = ""
replace issue = "Agriculture" if _n == 1
replace issue = "Civil Rights" if _n == 2
replace issue = "Defense" if _n == 3
replace issue = "Education" if _n == 4
replace issue = "Energy" if _n == 5
replace issue = "Public Transportation" if _n == 6
replace issue = "Senior Issues" if _n == 7
replace issue = "Welfare" if _n == 8
replace issue = "Pooled" if _n == 9
replace issue = "Placebo" if _n == 10
foreach i of varlist uninterested-difference_se {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
}
foreach i in uninterested interested difference {
replace `i' = `i' + " (" + `i'_se + ")"
}
drop *_se
order issue
save "Table2.dta", replace
browse


***Table A1***
clear
set more off
local cutoff = .1
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
g percentile = (_n - 1)/436
egen id = group(`i')
egen avg = mean(percentile), by(id)
sum avg
replace `i' = (avg - r(min))/(r(max) - r(min))
drop percentile id avg
}
rename poverty demo_welfare
rename military demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "cces_2006_common.dta"
replace v3001 = trim(v3001)
replace v3001 = "" if v3001 == "Christopher S. Bond" | v3001 == "Kay Bailey Hutchison"
destring v3001, replace
rename v1002 state
rename v1003 dist
drop if dist == 0
***Most important problem***
g defense = v2002 == 1 | v2002 == 2 | v3001 == 1 | v3001 == 2
g education = v2002 == 3 | v3001 == 3
g energy = v2002 == 6 | v3001 == 6
g welfare = v2002 == 9 | v2002 == 10 | v3001 == 9 | v3001 == 10
g senior = v2002 == 15 | v3001 == 15
foreach i in defense education energy welfare senior {
replace `i' = . if v2002 == . & v3001 == .
}
*Do you least want government to cut defense spending vs. cutting domestic spending, raising taxes, or borrowing
destring v4046, replace
g defensepriority = v4046 == 1
replace defensepriority = . if v4046 > 4
keep state dist defense* education energy welfare senior
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
reg defense demo_defense, r
outreg2 using TableA1, replace noaster dec(3)
reg education demo_education, r
outreg2 using TableA1, append noaster dec(3)
reg energy demo_energy, r
outreg2 using TableA1, append noaster dec(3)
reg senior demo_senior, r 
outreg2 using TableA1, append noaster dec(3)
reg welfare demo_welfare, r
outreg2 using TableA1, append noaster dec(3)
reg defensepriority demo_defense, r
outreg2 using TableA1, append noaster dec(3)


***Figure A1*** 
clear
set more off
postfile FigureA1 difference upper lower cutoff using "FigureA1.dta", replace
forvalues k = .05(.01).95 {
quietly {
clear
local cutoff = `k'
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
sum `i' if _n == 438 - ceil(437*`cutoff')
replace `i' = `i' >= r(mean)
}
rename poverty demo_welfare
rename military demo_defense
g demo_military = demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist cong
merge state dist cong using "HouseElectionResults.dta"
tab _merge
drop if _merge == 2
drop _merge
foreach i of varlist voteshare-absrv {
replace `i' = . if treatment != rep
}
drop treatment
egen state_dist = group(state dist)
egen state_dist_cong = group(state dist cong) 
reshape long cvp_ cvp_non_ demo_, i(state_dist_cong) j(issue) string
g rep_demo_ = rep*demo_
egen issue_cong_demo = group(issue cong demo_)
egen issue_cong = group(issue cong)
egen issue_dist = group(issue state_dist)
egen cong_demo = group(cong demo_)
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
forvalues j = 1/4 {
g rv`j'_`i' = 0
replace rv`j'_`i' = rv`j' if issue == "`i'"
g rv`j'_demo_`i' = rv`j'_`i'*demo_
}
}
forvalues j = 1/4 {
g rv`j'_demo = rv`j'*demo_
}

areg cvp_ rep rep_demo_ rv* if absrv < .5, a(issue_cong_demo) cluster(state_dist)
post FigureA1 (_b[rep_demo_]) (_b[rep_demo_] + invt(e(df_r),.025)*_se[rep_demo_]) (_b[rep_demo_] - invt(e(df_r),.025)*_se[rep_demo_]) (`k')
}
disp `k'
}
postclose FigureA1
clear
set more off
use "FigureA1.dta"
graph twoway line difference upper lower cutoff, yline(0)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Interest Cutoff
gr_edit .xaxis1.reset_rule .05 .95 .1 , tickset(major) ruletype(range) 
gr_edit .style.editstyle margin(vsmall) boxstyle(shadestyle(color(white)) linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Estimated Difference in Divergence
gr_edit .plotregion1.plot1.style.editstyle line(color(black) width(thick)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(color(black) pattern(dot)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(color(black) pattern(dot)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black) pattern(dash)) editcopy
graph save "FigureA1.gph", replace
graph export "FigureA1.eps", as(eps) replace


***Figure A2***
clear
set more off
local cutoff = .1
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
sum `i' if _n == 438 - ceil(437*`cutoff')
replace `i' = `i' >= r(mean)
}
rename poverty demo_welfare
rename military demo_defense
g demo_military = demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist cong
merge state dist cong using "HouseElectionResults.dta"
tab _merge
drop if _merge == 2
drop _merge
foreach i of varlist voteshare-absrv {
replace `i' = . if treatment != rep
}
drop treatment
egen state_dist = group(state dist)
egen state_dist_cong = group(state dist cong) 
reshape long cvp_ cvp_non_ demo_, i(state_dist_cong) j(issue) string
g rep_demo_ = rep*demo_
egen issue_cong_demo = group(issue cong demo_)
egen issue_cong = group(issue cong)
egen issue_dist = group(issue state_dist)
egen cong_demo = group(cong demo_)
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
forvalues j = 1/4 {
g rv`j'_`i' = 0
replace rv`j'_`i' = rv`j' if issue == "`i'"
g rv`j'_demo_`i' = rv`j'_`i'*demo_
}
}
forvalues j = 1/4 {
g rv`j'_demo = rv`j'*demo_
}
foreach i of varlist rv1* {
g int_`i' = `i'*rep
}
postfile FigureA2 difference upper lower bandwidth specification using "FigureA2.dta", replace
forvalues i = .025(.005).1 {
quietly {
areg cvp_ rep rep_demo_ if absrv < `i', a(issue_cong_demo) cluster(state_dist)
post FigureA2 (_b[rep_demo_]) (_b[rep_demo_] + invt(e(df_r),.025)*_se[rep_demo_]) (_b[rep_demo_] - invt(e(df_r),.025)*_se[rep_demo_]) (`i') (1)
}
disp `i'
}
forvalues i = .075(.005).25 {
quietly {
areg cvp_ rep rep_demo_ rv1* int_rv1* if absrv < `i', a(issue_cong_demo) cluster(state_dist)
post FigureA2 (_b[rep_demo_]) (_b[rep_demo_] + invt(e(df_r),.025)*_se[rep_demo_]) (_b[rep_demo_] - invt(e(df_r),.025)*_se[rep_demo_]) (`i') (2)
}
disp `i'
}
forvalues i = .15(.005).5 {
quietly {
areg cvp_ rep rep_demo_ rv* if absrv < `i', a(issue_cong_demo) cluster(state_dist)
post FigureA2 (_b[rep_demo_]) (_b[rep_demo_] + invt(e(df_r),.025)*_se[rep_demo_]) (_b[rep_demo_] - invt(e(df_r),.025)*_se[rep_demo_]) (`i') (3)
}
disp `i'
}
postclose FigureA2
clear
set more off
use "FigureA2.dta"
foreach i in difference upper lower {
g `i'1 = `i' if specification == 1
g `i'2 = `i' if specification == 2
g `i'3 = `i' if specification == 3
}
graph twoway line upper1 lower1 difference1 upper2 lower2 difference2 upper3 lower3 difference3 bandwidth, yline(0)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Bandwidth
gr_edit .xaxis1.reset_rule .05 .5 .05 , tickset(major) ruletype(range) 
gr_edit .style.editstyle margin(vsmall) boxstyle(shadestyle(color(white)) linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.title.text.Arrpush Estimated Difference in Divergence
gr_edit .plotregion1.plot3.style.editstyle line(color(gs12) width(thick)) editcopy
gr_edit .plotregion1.plot6.style.editstyle line(color(gs6) width(thick)) editcopy
gr_edit .plotregion1.plot9.style.editstyle line(color(black) width(thick)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(color(gs12) pattern(dot)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(color(gs12) pattern(dot)) editcopy
gr_edit .plotregion1.plot4.style.editstyle line(color(gs6) pattern(dot)) editcopy
gr_edit .plotregion1.plot5.style.editstyle line(color(gs6) pattern(dot)) editcopy
gr_edit .plotregion1.plot7.style.editstyle line(color(black) pattern(dot)) editcopy
gr_edit .plotregion1.plot8.style.editstyle line(color(black) pattern(dot)) editcopy
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black) pattern(dash)) editcopy
gr_edit .plotregion1.AddTextBox added_text editor .057 .019
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(gs12) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush Naive
gr_edit .plotregion1.AddTextBox added_text editor .05 .16
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(gs6) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush Local Linear
gr_edit .plotregion1.AddTextBox added_text editor .02 .32
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush Polynomial
graph save "FigureA2.gph", replace
graph export "FigureA2.eps", as(eps) replace


***Table A2*** 
clear
set more off
local cutoff = .1
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
sum `i' if _n == 438 - ceil(437*`cutoff')
replace `i' = `i' >= r(mean)
}
rename poverty demo_welfare
rename military demo_defense
g demo_military = demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "PresNormalVote.dta"
tab _merge
drop _merge
egen state_dist = group(state dist)
egen state_dist_cong = group(state dist cong) 
reshape long cvp_ cvp_non_ demo_, i(state_dist_cong) j(issue) string
g rep_demo_ = rep*demo_
egen issue_cong_demo = group(issue cong demo_)
egen issue_cong = group(issue cong)
egen issue_dist = group(issue state_dist)
egen cong_demo = group(cong demo_)
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
forvalues j = 1/4 {
g pres_norm_`j'_`i' = 0
replace pres_norm_`j'_`i' = pres_norm_`j' if issue == "`i'"
g pres_norm_`j'_demo_`i' = pres_norm_`j'_`i'*demo_
}
}
forvalues j = 1/4 {
g pres_norm_`j'_demo = pres_norm_`j'*demo_
}
postfile TableA2 uninterested uninterested_se interested interested_se difference difference_se using "TableA2.dta", replace
*issue-by-issue
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
areg cvp_ rep pres_norm_1-pres_norm_4 if issue == "`i'" & demo_ == 0, a(cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep] 
areg cvp_ rep pres_norm_1-pres_norm_4 if issue == "`i'" & demo_ == 1, a(cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ pres_norm_1-pres_norm_4 pres_norm_*_demo if issue == "`i'", a(cong_demo) cluster(state_dist)
post TableA2 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
}
*pooled
areg cvp_ rep pres* if demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_ rep pres* if demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ pres_*, a(issue_cong_demo) cluster(state_dist)
post TableA2 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
*placebo
areg cvp_non_ rep pres* if demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_non_ rep pres* if demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_non_ rep rep_demo_ pres_*, a(issue_cong_demo) cluster(state_dist)
post TableA2 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
postclose TableA2
clear
set more off
use "TableA2.dta"
g issue = ""
replace issue = "Agriculture" if _n == 1
replace issue = "Civil Rights" if _n == 2
replace issue = "Defense" if _n == 3
replace issue = "Education" if _n == 4
replace issue = "Energy" if _n == 5
replace issue = "Public Transportation" if _n == 6
replace issue = "Senior Issues" if _n == 7
replace issue = "Welfare" if _n == 8
replace issue = "Pooled" if _n == 9
replace issue = "Placebo" if _n == 10
foreach i of varlist uninterested-difference_se {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
}
foreach i in uninterested interested difference {
replace `i' = `i' + " (" + `i'_se + ")"
}
drop *_se
order issue
save "TableA2.dta", replace
browse


***Table A3***
clear
set more off
local cutoff = .1
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
sum `i' if _n == 438 - ceil(437*`cutoff')
replace `i' = `i' >= r(mean)
}
rename poverty demo_welfare
rename military demo_defense
g demo_military = demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist cong
egen state_dist = group(state dist)
egen state_dist_cong = group(state dist cong) 
reshape long cvp_ cvp_non_ demo_, i(state_dist_cong) j(issue) string
g rep_demo_ = rep*demo_
egen issue_cong_demo = group(issue cong demo_)
egen issue_cong = group(issue cong)
egen issue_dist = group(issue state_dist)
egen cong_demo = group(cong demo_)
postfile TableA3 uninterested uninterested_se interested interested_se difference difference_se using "TableA3.dta", replace
*issue-by-issue
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
xi:areg cvp_ rep i.cong if issue == "`i'" & demo_ == 0, a(state_dist) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep] 
xi:areg cvp_ rep i.cong if issue == "`i'" & demo_ == 1, a(state_dist) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
xi:areg cvp_ rep rep_demo_ i.cong_demo if issue == "`i'", a(state_dist) cluster(state_dist)
post TableA3 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
}
*pooled
xi:areg cvp_ rep i.issue_cong if demo_ == 0, a(issue_dist) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
xi:areg cvp_ rep i.issue_cong if demo_ == 1, a(issue_dist) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
xi:areg cvp_ rep rep_demo_ i.issue_cong_demo, a(issue_dist) cluster(state_dist)
post TableA3 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
*placebo
xi:areg cvp_non_ rep i.issue_cong if demo_ == 0, a(issue_dist) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
xi:areg cvp_non_ rep i.issue_cong if demo_ == 1, a(issue_dist) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
xi:areg cvp_non_ rep rep_demo_ i.issue_cong_demo, a(issue_dist) cluster(state_dist)
post TableA3 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
postclose TableA3
clear
set more off
use "TableA3.dta"
g issue = ""
replace issue = "Agriculture" if _n == 1
replace issue = "Civil Rights" if _n == 2
replace issue = "Defense" if _n == 3
replace issue = "Education" if _n == 4
replace issue = "Energy" if _n == 5
replace issue = "Public Transportation" if _n == 6
replace issue = "Senior Issues" if _n == 7
replace issue = "Welfare" if _n == 8
replace issue = "Pooled" if _n == 9
replace issue = "Placebo" if _n == 10
foreach i of varlist uninterested-difference_se {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
}
foreach i in uninterested interested difference {
replace `i' = `i' + " (" + `i'_se + ")"
}
drop *_se
order issue
save "TableA3.dta", replace
browse


***Table A4***
clear
set more off
local cutoff = .1
use "CensusData.dta"
foreach i of varlist poverty-over64 {
sort `i'
sum `i' if _n == 438 - ceil(437*`cutoff')
replace `i' = `i' >= r(mean)
}
rename poverty demo_welfare
rename military demo_defense
g demo_military = demo_defense
rename agriculture demo_agriculture
rename education demo_education
rename pubtrans demo_pubtrans
rename energy demo_energy
rename black demo_civilrights
rename over64 demo_senior
sort state dist
save "DistrictDemographics.dta", replace
clear
set more off
use "PartyRep.dta"
keep if meanrepublican == 0 | meanrepublican == 1
rename meanrepublican rep
sort state dist cong
merge state dist cong using "CVP.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist
merge state dist using "DistrictDemographics.dta"
tab _merge
keep if _merge == 3
drop _merge
sort state dist cong
merge state dist cong using "HouseElectionResults.dta"
tab _merge
drop if _merge == 2
drop _merge
foreach i of varlist voteshare-absrv {
replace `i' = . if treatment != rep
}
drop treatment
egen state_dist = group(state dist)
egen state_dist_cong = group(state dist cong) 
reshape long cvp_ cvp_non_ demo_, i(state_dist_cong) j(issue) string
g rep_demo_ = rep*demo_
egen issue_cong_demo = group(issue cong demo_)
egen issue_cong = group(issue cong)
egen issue_dist = group(issue state_dist)
egen cong_demo = group(cong demo_)
foreach i in agriculture civilrights defense education energy pubtrans senior welfare {
forvalues j = 1/4 {
g rv`j'_`i' = 0
replace rv`j'_`i' = rv`j' if issue == "`i'"
g rv`j'_demo_`i' = rv`j'_`i'*demo_
}
}
forvalues j = 1/4 {
g rv`j'_demo = rv`j'*demo_
}
sort issue state_dist cong
g lagged_rep = rep[_n-1] if state_dist == state_dist[_n-1] & issue == issue[_n-1]
g lagged_cvp = cvp_[_n-1] if state_dist == state_dist[_n-1] & issue == issue[_n-1]
postfile TableA4 uninterested uninterested_se interested interested_se difference difference_se using "TableA4.dta", replace
*Main specification
areg cvp_ rep rv* if absrv < .5 & demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_ rep rv* if absrv < .5 & demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ rv* if absrv < .5, a(issue_cong_demo) cluster(state_dist)
post TableA4 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
*Controlling for Lagged Incumbency
areg cvp_ rep lagged_rep rv* if absrv < .5 & demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_ rep lagged_rep rv* if absrv < .5 & demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ lagged_rep rv* if absrv < .5, a(issue_cong_demo) cluster(state_dist)
post TableA4 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
*Controlling for Lagged CVP
areg cvp_ rep lagged_cvp rv* if absrv < .5 & demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_ rep lagged_cvp rv* if absrv < .5 & demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ lagged_cvp rv* if absrv < .5, a(issue_cong_demo) cluster(state_dist)
post TableA4 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
*Donut
areg cvp_ rep rv* if absrv < .5 & absrv > .01 & demo_ == 0, a(issue_cong) cluster(state_dist)
scalar uninterested = _b[rep]
scalar uninterested_se = _se[rep]
areg cvp_ rep rv* if absrv < .5 & absrv > .01 & demo_ == 1, a(issue_cong) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp_ rep rep_demo_ rv* if absrv < .5 & absrv > .01, a(issue_cong_demo) cluster(state_dist)
post TableA4 (uninterested) (uninterested_se) (interested) (interested_se) (_b[rep_demo_]) (_se[rep_demo_])
postclose TableA4
clear
set more off
use "TableA4.dta"
g specification = ""
replace specification = "Baseline" if _n == 1
replace specification = "Controlling for Lagged Incumbency" if _n == 2
replace specification = "Controlling for Lagged CVP" if _n == 3
replace specification = "Donut" if _n == 4
foreach i of varlist uninterested-difference_se {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
}
foreach i in uninterested interested difference {
replace `i' = `i' + " (" + `i'_se + ")"
}
drop *_se
order specification
save "TableA4.dta", replace
browse


***Table A5***
clear
set more off
use "HouseElections_1952_2000.dta"
g cong = (year - 1786)/2
g cycle = floor((year - 2)/10)*10 + 2
egen state_dist = group(state dist)
egen state_dist_year = group(state dist year)
order state dist state_dist year cong cycle
sort state dist cycle
merge state dist cycle using "DistrictDemographics_1953_2002.dta"
keep if _merge == 3
drop _merge
g rv1 = voteshare - .5
forvalues i = 2/4 {
g rv`i' = rv1^`i'
}
g rep = rv1 > 0
g absrv = abs(rv1)
sort state dist cong
merge state dist cong using "CVP_83_107.dta"
keep if _merge == 3
drop _merge
reshape long demo_ cvp_, i(state_dist_year) j(issue) string
rename demo_ demo
rename cvp_ cvp
g rep_demo = rep*demo
forvalues i = 1/4 {
g demo_rv`i' = rv`i'*demo
}
egen cong_demo = group(cong demo)
scalar issuenum = 0
postfile TableA5 uninterested uninterested_se interested interested_se difference difference_se issue cycle using "TableA5.dta", replace
foreach i in agriculture defense {
scalar issuenum = issuenum + 1
forvalues j = 1952(10)1992 {
areg cvp rep rv* if issue == "`i'" & cycle == `j' & absrv < .5 & demo == 1, a(cong_demo) cluster(state_dist)
scalar interested = _b[rep]
scalar interested_se = _se[rep]
areg cvp rep rep_demo rv* demo_rv* if issue == "`i'" & cycle == `j' & absrv < .5, a(cong_demo) cluster(state_dist)
post TableA5 (_b[rep]) (_se[rep]) (interested) (interested_se) (_b[rep_demo]) (_se[rep_demo]) (issuenum) (`j') 
}
}
postclose TableA5
clear
set more off 
use "TableA5.dta"
foreach i of varlist uninterested-difference_se {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
}
foreach i in uninterested interested difference {
replace `i' = `i' + " (" + `i'_se + ")"
}
drop *_se
reshape wide uninterested interested difference, i(cycle) j(issue)
save "TableA5.dta", replace
browse
